Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2029)

Unified Diff: gclient.py

Issue 363103002: Update recurselist to be a set, call it recursedeps now. (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/depot_tools.git@master
Patch Set: update syntax Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | tests/gclient_test.py » ('j') | tests/gclient_test.py » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gclient.py
diff --git a/gclient.py b/gclient.py
index 50ebf9f3e2653afffd72782ac4d00cde7970f7db..a2d159a2c38445d3c9e49ccebc4bcdcde2810252 100755
--- a/gclient.py
+++ b/gclient.py
@@ -311,10 +311,10 @@ class Dependency(gclient_utils.WorkItem, DependencySettings):
# dependency. It is read from the actual DEPS file so cannot be set on
# class instantiation.
self.recursion_override = None
# recurselist is a mutable value that selectively overrides the default
# 'no recursion' setting on a dep-by-dep basis. It will replace
# recursion_override.
- self.recurselist = None
+ self.recursedeps = None
if not self.name and self.parent:
raise gclient_utils.Error('Dependency without name')
@@ -356,19 +356,19 @@ class Dependency(gclient_utils.WorkItem, DependencySettings):
return requirements
@property
- def try_recurselist(self):
+ def try_recursedeps(self):
"""Returns False if recursion_override is ever specified."""
if self.recursion_override is not None:
return False
- return self.parent.try_recurselist
+ return self.parent.try_recursedeps
@property
def recursion_limit(self):
"""Returns > 0 if this dependency is not too recursed to be processed."""
# We continue to support the absence of recurselist until tools and DEPS
# using recursion_override are updated.
- if self.try_recurselist and self.parent.recurselist != None:
- if self.name in self.parent.recurselist:
+ if self.try_recursedeps and self.parent.recursedeps != None:
+ if self.name in self.parent.recursedeps:
return 1
if self.recursion_override is not None:
@@ -593,9 +593,9 @@ class Dependency(gclient_utils.WorkItem, DependencySettings):
self.recursion_override = local_scope.get('recursion')
logging.warning(
'Setting %s recursion to %d.', self.name, self.recursion_limit)
- self.recurselist = local_scope.get('recurselist', None)
- if 'recurselist' in local_scope:
- logging.warning('Found recurselist %r.', repr(self.recurselist))
+ self.recursedeps = local_scope.get('recursedeps', None)
iannucci 2014/07/03 18:55:59 could also cast to a set here. If it's already a s
+ if 'recursedeps' in local_scope:
+ logging.warning('Found recursedeps %r.', repr(self.recursedeps))
# If present, save 'target_os' in the local_target_os property.
if 'target_os' in local_scope:
self.local_target_os = local_scope['target_os']
@@ -1490,8 +1490,8 @@ want to set 'managed': False in .gclient.
return self._recursion_limit
@property
- def try_recurselist(self):
- """Whether to attempt using recurselist-style recursion processing."""
+ def try_recursedeps(self):
+ """Whether to attempt using recursedeps-style recursion processing."""
return True
@property
« no previous file with comments | « no previous file | tests/gclient_test.py » ('j') | tests/gclient_test.py » ('J')

Powered by Google App Engine
@@ -311,10 +311,10 @@ class Dependency(gclient_utils.WorkItem, DependencySettings):
# class instantiation.
self.recursion_override = None
- # recurselist is a mutable value that selectively overrides the default
+ # recursedeps is a mutable value that selectively overrides the default
# 'no recursion' setting on a dep-by-dep basis. It will replace
# recursion_override.
@@ -356,19 +356,19 @@ class Dependency(gclient_utils.WorkItem, DependencySettings):
def recursion_limit(self):
"""Returns > 0 if this dependency is not too recursed to be processed."""
- # We continue to support the absence of recurselist until tools and DEPS
+ # We continue to support the absence of recursedeps until tools and DEPS
# using recursion_override are updated.
This is Rietveld 408576698